@@ -563,9 +563,9 @@ class AlarmedGUI(QtGui.QWidget):
         s = self.fields["schedules"]
         i = self.fields["intervals"]
         t = self.fields["types"]
-        eventInfo["schedule"] = str(self.schedulePicker.currentText())
-        eventInfo["type"] = str(self.typePicker.currentText())
-        eventInfo["title"] = str(self.titlePicker.text())
+        eventInfo["schedule"] = self.schedulePicker.currentText()
+        eventInfo["type"] = self.typePicker.currentText()
+        eventInfo["title"] = self.titlePicker.text()
         if self.schedulePicker.currentText() in [s["weekly"],
                                                  s["biweekly"]]:
             if not self.weekdays:
@@ -587,7 +587,7 @@ class AlarmedGUI(QtGui.QWidget):
             dateTime = dateTime.addSecs(secs)
             eventInfo["ttime"] = int(dateTime.toTime_t())
             eventInfo["number"] = int(self.numberPicker.value())
-            eventInfo["interval"] = str(self.intervalPicker.currentText())
+            eventInfo["interval"] = self.intervalPicker.currentText()
         elif self.schedulePicker.currentText() == s["next"]:
             day = self.rWeekdayPicker.currentText()
             if day == mon: day = 1
@@ -622,7 +622,7 @@ class AlarmedGUI(QtGui.QWidget):
             eventInfo["ttime"] = int(time.mktime(td.timetuple()))
             eventInfo["cron"] = cronstring
         elif self.schedulePicker.currentText() == s["date"]:
-            eventInfo["date"] = str(self.datesyntaxPicker.text())
+            eventInfo["date"] = self.datesyntaxPicker.text()
             ttime = alarmed_backend.interpretDateString(
                                     eventInfo["date"])
             if not ttime[0]:
@@ -641,13 +641,13 @@ class AlarmedGUI(QtGui.QWidget):
         type = self.typePicker.currentText()
         content = ""
         if type == t["exec_type"]:
-            content = str(self.execPicker.text())
+            content = self.execPicker.text()
             eventInfo["content"] = content
         elif type == t["builtin_type"]:
-            content = str(self.builtinPicker.currentText())
+            content = self.builtinPicker.currentText()
             eventInfo["content"] = content
         elif type == t["profile_type"]:
-            content = str(self.profilePicker.currentText())
+            content = self.profilePicker.currentText()
             eventInfo["content"] = content
         if self.weekdays:
             eventInfo["weekdays"] = self.weekdays
